==> net.java.html.lib-0.3-sources.jar: net/java/html/lib/ArrayBuffer.java <==
package net.java.html.lib;
public class ArrayBuffer extends net.java.html.lib.Objs {
  protected ArrayBuffer(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<ArrayBuffer> {
    $Constructor() {
      super(ArrayBuffer.class);
    }
    @Override
    public ArrayBuffer create(java.lang.Object obj) {
      return obj == null ? null : new ArrayBuffer(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static ArrayBuffer $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  /**
  * Read-only. The length of the ArrayBuffer (in bytes).
  */
  public net.java.html.lib.Objs.Property<java.lang.Number> byteLength = net.java.html.lib.Objs.Property.create(this, java.lang.Number.class, "byteLength");
  public java.lang.Number byteLength() { return byteLength.get(); }
  /**
  * Returns a section of an ArrayBuffer.
  */
  public ArrayBuffer slice(double begin, double end) {
    return (ArrayBuffer)net.java.html.lib.ArrayBuffer.$as($Typings$.slice$13($js(this), begin, end));
  }
  /**
  * Returns a section of an ArrayBuffer.
  */
  public ArrayBuffer slice(double begin) {
    return (ArrayBuffer)net.java.html.lib.ArrayBuffer.$as($Typings$.slice$14($js(this), begin));
  }
  // constructor ArrayBufferConstructor
  public static ArrayBuffer prototype = (ArrayBuffer)net.java.html.lib.ArrayBuffer.$as($Typings$.readStaticFields$15());
  public static java.lang.Boolean isView(java.lang.Object arg) {
    return $Typings$.isView$16(/* AnyKeyword*/$js(arg));
  }
  public ArrayBuffer(double byteLength) {
    this(ArrayBuffer.$AS, $Typings$.new$17(byteLength));
  }
}

==> net.java.html.lib-0.5-sources.jar: net/java/html/lib/ArrayBuffer.java <==
package net.java.html.lib;
public class ArrayBuffer extends net.java.html.lib.Objs {
  protected ArrayBuffer(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<ArrayBuffer> {
    $Constructor() {
      super(ArrayBuffer.class);
    }
    @Override
    public ArrayBuffer create(java.lang.Object obj) {
      return obj == null ? null : new ArrayBuffer(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static ArrayBuffer $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  /**
  * Read-only. The length of the ArrayBuffer (in bytes).
  */
  public net.java.html.lib.Objs.Property<java.lang.Number> byteLength = net.java.html.lib.Objs.Property.create(this, java.lang.Number.class, "byteLength");
  public java.lang.Number byteLength() { return byteLength.get(); }
  /**
  * Returns a section of an ArrayBuffer.
  */
  public net.java.html.lib.ArrayBuffer slice(double begin, double end) {
    return (net.java.html.lib.ArrayBuffer)net.java.html.lib.ArrayBuffer.$as($Typings$.slice$13($js(this), begin, end));
  }
  /**
  * Returns a section of an ArrayBuffer.
  */
  public net.java.html.lib.ArrayBuffer slice(double begin) {
    return (net.java.html.lib.ArrayBuffer)net.java.html.lib.ArrayBuffer.$as($Typings$.slice$14($js(this), begin));
  }
  // constructor ArrayBufferConstructor
  public static net.java.html.lib.ArrayBuffer prototype = (net.java.html.lib.ArrayBuffer)net.java.html.lib.ArrayBuffer.$as($Typings$.readStaticFields$15());
  public static java.lang.Boolean isView(java.lang.Object arg) {
    return $Typings$.isView$16(/* AnyKeyword*/$js(arg));
  }
  public ArrayBuffer(double byteLength) {
    this(ArrayBuffer.$AS, $Typings$.new$17(byteLength));
  }
}
